BEGIN TRANSACTION;

DROP TABLE IF EXISTS test1;
DROP TABLE IF EXISTS test2;
DROP TABLE IF EXISTS test3;

CREATE TABLE test1 (
    id INTEGER PRIMARY KEY AUTOINCREMENT,
    name TEXT NOT NULL,
    description TEXT 
);

CREATE TABLE test2 (
    id INTEGER PRIMARY KEY AUTOINCREMENT,
    name TEXT NOT NULL,
    description TEXT 
);

CREATE TABLE test3 (
    id INTEGER PRIMARY KEY,
    name TEXT NOT NULL
);

COMMIT;
